@@ -37,7 +37,8 @@ func TestStory(t *testing.T) {
 	runOutFile := filepath.Join(tmpDir, "run-log.txt")
 
 	command := cmd.RootCmd()
-	command.SetArgs([]string{"run",
+	command.SetArgs([]string{
+		"run",
 		"--output", runOutFile,
 		"--author-name", "Test Author",
 		"--author-email", "test@example.com",
@@ -75,7 +76,8 @@ Repositories with a successful run:
 	statusOutFile := filepath.Join(tmpDir, "status-log.txt")
 
 	command = cmd.RootCmd()
-	command.SetArgs([]string{"status",
+	command.SetArgs([]string{
+		"status",
 		"--output", statusOutFile,
 		"-B", "custom-branch-name",
 	})
@@ -96,7 +98,8 @@ Repositories with a successful run:
 	mergeLogFile := filepath.Join(tmpDir, "merge-log.txt")
 
 	command = cmd.RootCmd()
-	command.SetArgs([]string{"merge",
+	command.SetArgs([]string{
+		"merge",
 		"--log-file", mergeLogFile,
 		"-B", "custom-branch-name",
 	})
@@ -115,7 +118,8 @@ Repositories with a successful run:
 	afterMergeStatusOutFile := filepath.Join(tmpDir, "after-merge-status-log.txt")
 
 	command = cmd.RootCmd()
-	command.SetArgs([]string{"status",
+	command.SetArgs([]string{
+		"status",
 		"--output", afterMergeStatusOutFile,
 		"-B", "custom-branch-name",
 	})
@@ -133,7 +137,8 @@ Repositories with a successful run:
 	closeLogFile := filepath.Join(tmpDir, "close-log.txt")
 
 	command = cmd.RootCmd()
-	command.SetArgs([]string{"close",
+	command.SetArgs([]string{
+		"close",
 		"--log-file", closeLogFile,
 		"-B", "custom-branch-name",
 	})
@@ -152,7 +157,8 @@ Repositories with a successful run:
 	afterCloseStatusOutFile := filepath.Join(tmpDir, "after-close-status-log.txt")
 
 	command = cmd.RootCmd()
-	command.SetArgs([]string{"status",
+	command.SetArgs([]string{
+		"status",
 		"--output", afterCloseStatusOutFile,
 		"-B", "custom-branch-name",
 	})
